"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const create_rule_1 = require("../internal/create-rule");
// eslint-disable-next-line @typescript-eslint/ban-ts-comment
// @ts-ignore
const types_1 = require("@typescript-eslint/types");
const ASSERTION_EXPRESSION_NAMES = ['assert', 'always', 'never'];
module.exports = (0, create_rule_1.createRule)({
    name: "no-explicit-boolean",
    meta: {
        type: 'suggestion',
        docs: {
            description: 'Disallows calling always/never/assert with just a boolean.',
            // category: 'Best Practices',
            // recommended: 'error'
        },
        messages: {
            bool: "boolean",
        },
        schema: [{
                type: 'array',
                items: {
                    type: 'string'
                },
            }]
    },
    defaultOptions: [[]],
    create: (context) => {
        return {
            CallExpression: (node) => {
                if (ASSERTION_EXPRESSION_NAMES.includes(node.callee.name)) {
                    const conditionArgument = node.arguments[0];
                    if (conditionArgument.type === types_1.AST_NODE_TYPES.Literal) {
                        return checkLiteral(conditionArgument);
                    }
                    if (conditionArgument.type === types_1.AST_NODE_TYPES.LogicalExpression) {
                        return checkLogicalExpression(conditionArgument);
                    }
                }
                function checkLiteral(expression) {
                    const value = expression.value;
                    if (value === true || value === false) {
                        return context.report({
                            node: expression,
                            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                            // @ts-ignore
                            message: getFailureString(expression.value)
                        });
                    }
                }
                function checkLogicalExpression(expression) {
                    ['left', 'right'].forEach(sideName => {
                        const side = expression[sideName];
                        if (side.type === types_1.AST_NODE_TYPES.Literal) {
                            checkLiteral(side);
                        }
                        else if (side.type === types_1.AST_NODE_TYPES.LogicalExpression) {
                            checkLogicalExpression(side);
                        }
                    });
                }
                function getFailureString(bool) {
                    return `Assertions cannot be called with condition that is always ${bool}`;
                }
            }
        };
    }
});
//# sourceMappingURL=no-explicit-boolean.js.map